@@ -46,15 +46,6 @@ class AbstractAccount : public QObject
     Q_PROPERTY(int unreadNotificationsCount READ unreadNotificationsCount NOTIFY unreadNotificationsCountChanged)
 
 public:
-    /**
-     * @brief Register the application on the server.
-     * @param appName The name of the application displayed to other clients.
-     * @param website The application's website.
-     * @param additionalScopes Any additional scopes to request.
-     * @param useAuthCode If the auth code method should be used instead of an ouath callback.
-     */
-    void registerApplication(const QString &appName, const QString &website, const QString &additionalScopes = {}, bool useAuthCode = false);
-
     /**
      * @brief Register a new account on the server.
      * @param username The account's username.
@@ -68,10 +59,9 @@ public:
     registerAccount(const QString &username, const QString &email, const QString &password, bool agreement, const QString &locale, const QString &reason);
 
     /**
-     * @return If the application is registered
-     * @sa registerApplication
+     * @return If the account has successfully authenticated with the server.
      */
-    [[nodiscard]] bool isRegistered() const;
+    virtual bool successfullyAuthenticated() const = 0;
 
     /**
      * @return If this account's instance has registrations open.
@@ -88,17 +78,6 @@ public:
      */
     Q_INVOKABLE [[nodiscard]] QUrl getAuthorizeUrl() const;
 
-    /**
-     * @brief Sets the access token.
-     * @param token The access token.
-     */
-    void setAccessToken(const QString &token);
-
-    /**
-     * @return The oauth2 token url.
-     */
-    [[nodiscard]] QUrl getTokenUrl() const;
-
     /**
      * @brief Set the oauth2 token.
      * @param authcode The oauth2 authentication code.
@@ -116,15 +95,10 @@ public:
      */
     [[nodiscard]] bool hasName() const;
 
-    /**
-     * @return If the account has an instance uri set.
-     */
-    [[nodiscard]] bool hasInstanceUrl() const;
-
     /**
      * @brief Verifies the token with the instance and if successful, loads identity information for the account.
      */
-    Q_INVOKABLE virtual void validateToken(bool newAccount = false) = 0;
+    Q_INVOKABLE virtual void validateToken() = 0;
 
     /**
      * @return The local account preferences.
@@ -142,22 +116,11 @@ public:
      */
     [[nodiscard]] QString username() const;
 
-    /**
-     * @brief Sets the username for the account.
-     * @param name The new username.
-     */
-    void setUsername(const QString &name);
-
     /**
      * @brief Fetches instance-specific metadata like max post length, allowed content types, etc.
      */
     void fetchInstanceMetadata();
 
-    /**
-     * @brief Fetches instance-specific custom emojis.
-     */
-    void fetchCustomEmojis();
-
     /**
      * @return The custom emojis that's accessible for this account.
      */
@@ -169,12 +132,6 @@ public:
      */
     [[nodiscard]] QString instanceUri() const;
 
-    /**
-     * @brief Sets the instance URI for the account.
-     * @param instance_uri The new instance URI.
-     */
-    void setInstanceUri(const QString &instance_uri);
-
     /**
      * @return The max allowable length of posts in characters.
      */
@@ -240,11 +197,6 @@ public:
      */
     std::shared_ptr<ReportInfo> reportInfoLookup(const QString &reportId, const QJsonObject &doc);
 
-    /**
-     * @brief Invalidates this account.
-     */
-    void invalidate();
-
     /**
      * @brief Saves the timeline position.
      * @param timeline Which timeline to save, right now can only be "home" or "notifications"
@@ -314,26 +266,6 @@ public:
      */
     QUrl streamingUrl(const QString &stream);
 
-    /**
-     * @brief Invalidates a post.
-     * @param p The post object to mutate.
-     */
-    void invalidatePost(Post *p);
-
-    /**
-     * @brief Types of formatting that we may use is determined primarily by the server metadata, this is a simple enough way to determine what formats are
-     * accepted.
-     */
-    enum AllowedContentType { PlainText = 1 << 0, Markdown = 1 << 1, Html = 1 << 2, BBCode = 1 << 3 };
-
-    /**
-     * @return The allowed content types of the account's instance.
-     */
-    [[nodiscard]] AllowedContentType allowedContentTypes() const
-    {
-        return m_allowedContentTypes;
-    }
-
     /**
      * @param path The base API path.
      * @return A well-formed URL of an API path.
@@ -600,6 +532,7 @@ public:
      * @brief Type of streaming event.
      */
     enum StreamingEventType {
+        InvalidEvent, /**< The server returned an invalid event type. */
         UpdateEvent, /**< A new Status has appeared. */
         DeleteEvent, /**< A status has been deleted. */
         NotificationEvent, /**< A new notification has appeared. */
@@ -639,12 +572,6 @@ Q_SIGNALS:
      */
     void fetchedTimeline(const QString &timelineName, QList<Post *> posts);
 
-    /**
-     * @brief Emitted when th=e account has been invalidated
-     * @see invalidate()
-     */
-    void invalidated();
-
     /**
      * @brief Emitted when the account's username has been changed.
      * @see setUsername()
@@ -663,13 +590,6 @@ Q_SIGNALS:
      */
     void fetchedCustomEmojis();
 
-    /**
-     * @brief Emitted when a post has been invalidated.
-     * @param p The post that was invalidated.
-     * @see invalidatePost()
-     */
-    void invalidatedPost(Post *p);
-
     /**
      * @brief Emitted when a notification has been received.
      * @param n A shared handle to the new notification.
@@ -712,8 +632,39 @@ Q_SIGNALS:
     void fetchedOEmbed(const QString &html);
 
 protected:
-    AbstractAccount(QObject *parent, const QString &instanceUri);
-    explicit AbstractAccount(QObject *parent);
+    explicit AbstractAccount(const QString &instanceUri, QObject *parent = nullptr);
+
+    /**
+     * @brief Register the application on the server.
+     * @param appName The name of the application displayed to other clients.
+     * @param website The application's website.
+     * @param additionalScopes Any additional scopes to request.
+     * @param useAuthCode If the auth code method should be used instead of an ouath callback.
+     */
+    void registerApplication(const QString &appName, const QString &website, const QString &additionalScopes = {}, bool useAuthCode = false);
+
+    /**
+     * @brief Sets the username for the account.
+     * @param name The new username.
+     */
+    void setUsername(const QString &name);
+
+    /**
+     * @brief Sets the instance URI for the account.
+     * @param instance_uri The new instance URI.
+     */
+    void setInstanceUri(const QString &instance_uri);
+
+    /**
+     * @brief Fetches instance-specific custom emojis.
+     */
+    void fetchCustomEmojis();
+
+    /**
+     * @brief Sets the access token.
+     * @param token The access token.
+     */
+    void setAccessToken(const QString &token);
 
     QString m_name;
     QString m_instance_uri;
@@ -728,10 +679,9 @@ protected:
     QJsonArray m_instance_rules;
     std::shared_ptr<Identity> m_identity;
     std::shared_ptr<AdminAccountInfo> m_adminIdentity;
-    AdminAccountInfo *m_adminIdentityWithVanillaPointer;
-    AdminAccountInfo *m_federationIdentity;
+    AdminAccountInfo *m_adminIdentityWithVanillaPointer{};
+    AdminAccountInfo *m_federationIdentity{};
     std::shared_ptr<ReportInfo> m_reportInfo;
-    AllowedContentType m_allowedContentTypes;
     Preferences *m_preferences = nullptr;
     QList<CustomEmoji> m_customEmojis;
     QString m_additionalScopes;
@@ -742,9 +692,6 @@ protected:
     int m_unreadNotificationsCount = 0;
     QString m_redirectUri;
 
-    // OAuth authorization
-    [[nodiscard]] QUrlQuery buildOAuthQuery() const;
-
     // updates and notifications
     void handleNotification(const QJsonDocument &doc);
 
@@ -755,4 +702,9 @@ protected:
     QMap<QString, std::shared_ptr<ReportInfo>> m_reportInfoCache;
 
     void executeAction(Identity *i, AccountAction accountAction, const QJsonObject &extraArguments = {});
+
+    friend class MockAccount;
+    friend class AccountTest;
+    friend class ProfileEditorTest;
+    friend class TimelineTest;
 };
