@@ -15,20 +15,12 @@ using namespace Qt::Literals::StringLiterals;
 
 AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
-    , m_selected_account(nullptr)
     , m_qnam(NetworkAccessManagerFactory().create(this))
     , m_notificationHandler(new NotificationHandler(m_qnam, this))
 {
 }
 
-AccountManager::~AccountManager()
-{
-    for (auto a : std::as_const(m_accounts)) {
-        delete a;
-    }
-
-    m_accounts.clear();
-}
+AccountManager::~AccountManager() = default;
 
 QVariant AccountManager::data(const QModelIndex &index, int role) const
 {
@@ -37,30 +29,34 @@ QVariant AccountManager::data(const QModelIndex &index, int role) const
     }
 
     auto account = m_accounts.at(index.row());
-    if (account->identity() == nullptr) {
+    if (!account->identity()) {
         return {};
     }
+
     switch (role) {
     case Qt::DisplayRole:
-    case DisplayNameRole:
-        if (!account->identity()->displayNameHtml().isEmpty())
+    case DisplayNameRole: {
+        if (!account->identity()->displayNameHtml().isEmpty()) {
             return account->identity()->displayNameHtml();
-        else
-            return account->username();
+        }
+
+        return account->username();
+    }
     case DescriptionRole:
         return account->identity()->account();
     case InstanceRole:
         return account->instanceName();
     case AccountRole:
         return QVariant::fromValue(m_accounts[index.row()]);
+    default:
+        return {};
     }
-    return {};
 }
 
 int AccountManager::rowCount(const QModelIndex &index) const
 {
     Q_UNUSED(index)
-    return m_accounts.size();
+    return static_cast<int32_t>(m_accounts.size());
 }
 
 QHash<int, QByteArray> AccountManager::roleNames() const
@@ -80,9 +76,9 @@ AccountManager &AccountManager::instance()
     return accountManager;
 }
 
-AbstractAccount *AccountManager::createNewAccount(const QString &instanceUri, bool ignoreSslErrors, bool admin)
+AbstractAccount *AccountManager::createNewAccount(const QString &instanceUri)
 {
-    return new Account(instanceUri, m_qnam, ignoreSslErrors, admin, this);
+    return new Account(instanceUri, m_qnam, this);
 }
 
 bool AccountManager::hasAccounts() const
@@ -100,17 +96,13 @@ NotificationHandler *AccountManager::notificationHandler() const
     return m_notificationHandler;
 }
 
-void AccountManager::addAccount(AbstractAccount *account, bool skipAuthenticationCheck)
+void AccountManager::addAccount(AbstractAccount *account)
 {
     beginInsertRows(QModelIndex(), m_accounts.size(), m_accounts.size());
     m_accounts.append(account);
-    int acctIndex = m_accountStatus.size();
-    if (!skipAuthenticationCheck) {
-        if (m_testMode) {
-            m_accountStatus.push_back(AccountStatus::Loaded);
-        } else {
-            m_accountStatus.push_back(AccountStatus::NotLoaded);
-        }
+    int const acctIndex = m_accountStatus.size();
+    if (!account->successfullyAuthenticated()) {
+        m_accountStatus.push_back(AccountStatus::NotLoaded);
         m_accountStatusStrings.push_back({});
     }
     endInsertRows();
@@ -121,7 +113,7 @@ void AccountManager::addAccount(AbstractAccount *account, bool skipAuthenticatio
         childIdentityChanged(account);
         account->writeToSettings();
     });
-    if (!skipAuthenticationCheck) {
+    if (!account->successfullyAuthenticated()) {
         connect(account, &Account::authenticated, this, [this, acctIndex](const bool authenticated, const QString &errorMessage) {
             if (authenticated) {
                 m_accountStatus[acctIndex] = AccountStatus::Loaded;
@@ -129,26 +121,15 @@ void AccountManager::addAccount(AbstractAccount *account, bool skipAuthenticatio
                 m_accountStatus[acctIndex] = AccountStatus::InvalidCredentials;
                 m_accountStatusStrings[acctIndex] = errorMessage;
             }
-            Q_EMIT dataChanged(index(0, 0), index(m_accounts.size() - 1, 0));
+            Q_EMIT dataChanged(index(acctIndex, 0), index(acctIndex, 0));
+            checkIfLoadingFinished();
         });
     }
-
-    connect(account, &Account::fetchedTimeline, this, [this, account](const QString &original_name, QList<Post *> posts) {
-        Q_EMIT fetchedTimeline(account, original_name, std::move(posts));
-    });
-    connect(account, &Account::invalidated, this, [this, account]() {
-        Q_EMIT invalidated(account);
-    });
-    connect(account, &Account::fetchedInstanceMetadata, this, [this, account]() {
-        Q_EMIT fetchedInstanceMetadata(account);
-        Q_EMIT dataChanged(index(0, 0), index(m_accounts.size() - 1, 0));
-    });
-    connect(account, &Account::invalidatedPost, this, [this, account](Post *p) {
-        Q_EMIT invalidatedPost(account, p);
+    connect(account, &Account::fetchedInstanceMetadata, this, [this, account, acctIndex]() {
+        Q_EMIT dataChanged(index(acctIndex, 0), index(acctIndex, 0));
     });
     connect(account, &Account::notification, this, [this, account](std::shared_ptr<Notification> n) {
-        AccountManager::instance().notificationHandler()->handle(std::move(n), account);
-        Q_EMIT notification(account, std::move(n));
+        notificationHandler()->handle(std::move(n), account);
     });
 
     if (m_selected_account == nullptr) {
@@ -255,7 +236,7 @@ QString AccountManager::selectedAccountLoginIssue() const
 void AccountManager::selectAccount(AbstractAccount *account, bool explicitUserAction)
 {
     if (!m_accounts.contains(account)) {
-        qDebug() << "WTF: attempt to select unmanaged account" << account;
+        qCWarning(TOKODON_LOG) << "WTF: attempt to select unmanaged account" << account;
         return;
     }
 
@@ -277,17 +258,15 @@ AbstractAccount *AccountManager::selectedAccount() const
 
 QString AccountManager::selectedAccountId() const
 {
+    if (!m_selected_account) {
+        return {};
+    }
     return m_selected_account->identity()->id();
 }
 
 int AccountManager::selectedIndex() const
 {
-    for (int i = 0; i < m_accounts.length(); i++) {
-        if (m_selected_account == m_accounts[i]) {
-            return i;
-        }
-    }
-    return -1;
+    return m_accounts.indexOf(m_selected_account);
 }
 
 void AccountManager::loadFromSettings()
@@ -302,47 +281,31 @@ void AccountManager::loadFromSettings()
     auto config = KSharedConfig::openStateConfig();
     for (const auto &id : config->groupList()) {
         if (id.contains('@'_L1)) {
-            auto accountConfig = new AccountConfig{id};
+            // The id is normally made up of two parts. <username>@<instance>
+            // If one of them is missing, consider the key invalid. Otherwise we may end up with duplicate accounts.
+            const QStringList idParts = id.split('@'_L1, Qt::SkipEmptyParts);
+            if (idParts.size() != 2) {
+                config->deleteGroup(id);
+                continue;
+            }
+
+            const auto accountConfig = new AccountConfig{id};
 
             if (accountConfig->clientId().isEmpty() || accountConfig->instanceUri().isEmpty()) {
+                config->deleteGroup(id);
                 accountConfig->deleteLater();
                 continue;
             }
 
-            const int index = m_accountStatus.size();
-            m_accountStatus.push_back(AccountStatus::NotLoaded);
-            m_accountStatusStrings.push_back({});
-
-            auto account = new Account(accountConfig, m_qnam);
-            addAccount(account, true);
-
-            connect(account, &Account::authenticated, this, [this, account, index](const bool successful, const QString &errorMessage) {
-                if (successful && account->haveToken() && account->hasName() && account->hasInstanceUrl()) {
-                    m_accountStatus[index] = AccountStatus::Loaded;
-                } else {
-                    m_accountStatus[index] = AccountStatus::InvalidCredentials;
-                    m_accountStatusStrings[index] = errorMessage;
-                }
-
-                checkIfLoadingFinished();
-            });
+            const auto account = new Account(accountConfig->instanceUri(), m_qnam, this);
+            account->setConfig(accountConfig);
+            addAccount(account);
         }
     }
 
     checkIfLoadingFinished();
 }
 
-KAboutData AccountManager::aboutData() const
-{
-    return m_aboutData;
-}
-
-void AccountManager::setAboutData(const KAboutData &aboutData)
-{
-    m_aboutData = aboutData;
-    Q_EMIT aboutDataChanged();
-}
-
 void AccountManager::checkIfLoadingFinished()
 {
     // no accounts at all
@@ -352,12 +315,10 @@ void AccountManager::checkIfLoadingFinished()
         return;
     }
 
-    bool finished = true;
-    for (auto status : m_accountStatus) {
-        if (status == AccountStatus::NotLoaded)
-            finished = false;
-    }
-
+    // ensure every account is loaded, or has an error
+    const bool finished = std::none_of(m_accountStatus.cbegin(), m_accountStatus.cend(), [](const auto status) {
+        return status == AccountStatus::NotLoaded;
+    });
     if (!finished) {
         return;
     }
@@ -366,18 +327,21 @@ void AccountManager::checkIfLoadingFinished()
 
     auto config = Config::self();
 
-    for (auto account : m_accounts) {
-        // old LastUsedAccount values used to be only username
-        const bool isOldVersion = !config->lastUsedAccount().contains(QLatin1Char('@'));
-        const bool isEmpty = config->lastUsedAccount().isEmpty() || config->lastUsedAccount() == '@'_L1;
-        const bool matchesNewFormat = account->settingsGroupName() == config->lastUsedAccount();
-        const bool matchesOldFormat = account->username() == config->lastUsedAccount();
+    // Test code manually selects the account
+    if (!m_testMode) {
+        for (auto account : m_accounts) {
+            // old LastUsedAccount values used to be only username
+            const bool isOldVersion = !config->lastUsedAccount().contains(QLatin1Char('@'));
+            const bool isEmpty = config->lastUsedAccount().isEmpty() || config->lastUsedAccount() == '@'_L1;
+            const bool matchesNewFormat = account->settingsGroupName() == config->lastUsedAccount();
+            const bool matchesOldFormat = account->username() == config->lastUsedAccount();
 
-        const bool isValid = isEmpty || (isOldVersion ? matchesOldFormat : matchesNewFormat);
+            const bool isValid = isEmpty || (isOldVersion ? matchesOldFormat : matchesNewFormat);
 
-        if (isValid) {
-            selectAccount(account, false);
-            break;
+            if (isValid) {
+                selectAccount(account, false);
+                break;
+            }
         }
     }
 
@@ -394,7 +358,7 @@ QString AccountManager::settingsGroupName(const QString &name, const QString &in
 {
     Q_ASSERT(!name.isEmpty());
     Q_ASSERT(!instanceUri.isEmpty());
-    return QStringLiteral("%1@%2").arg(name, QUrl(instanceUri).host());
+    return QStringLiteral("%1@%2").arg(name, QUrl::fromUserInput(instanceUri).host());
 }
 
 QString AccountManager::clientSecretKey(const QString &name)
@@ -409,7 +373,7 @@ QString AccountManager::clientSecretKey(const QString &name)
 QString AccountManager::accessTokenKey(const QString &name)
 {
 #ifdef TOKODON_FLATPAK
-    return QStringLiteral("%1-flatpak-  client-secret").arg(name);
+    return QStringLiteral("%1-flatpak-access-token").arg(name);
 #else
     return QStringLiteral("%1-access-token").arg(name);
 #endif
@@ -474,7 +438,6 @@ void AccountManager::migrateSettings()
             config.setClientId(settings.value("client_id").toString());
             config.setInstanceUri(settings.value("instance_uri").toString());
             config.setName(settings.value("name").toString());
-            config.setIgnoreSslErrors(settings.value("ignoreSslErrors").toBool());
 
             config.save();
 
@@ -530,16 +493,12 @@ void AccountManager::queueNotifications()
     };
 
     for (auto account : m_accounts) {
-        QUrl uri;
-        uri = QUrl::fromUserInput(account->instanceUri());
-        uri.setPath(QStringLiteral("/api/v1/notifications"));
-
-        AccountConfig config(account->settingsGroupName());
+        QUrl uri = account->apiUrl(QStringLiteral("/api/v1/notifications"));
 
         QUrlQuery urlQuery(uri);
         urlQuery.addQueryItem(QStringLiteral("limit"), QString::number(10));
-        if (!config.lastPushNotification().isEmpty()) {
-            urlQuery.addQueryItem(QStringLiteral("since_id"), config.lastPushNotification());
+        if (!account->config()->lastPushNotification().isEmpty()) {
+            urlQuery.addQueryItem(QStringLiteral("since_id"), account->config()->lastPushNotification());
         }
         uri.setQuery(urlQuery);
 
@@ -569,9 +528,8 @@ void AccountManager::queueNotifications()
                     }
                 }
 
-                AccountConfig config(account->settingsGroupName());
-                config.setLastPushNotification(doc.array().first()["id"_L1].toString());
-                config.save();
+                account->config()->setLastPushNotification(doc.array().first()["id"_L1].toString());
+                account->config()->save();
 
                 totalNotifications = doc.array().size();
 
