@@ -34,6 +34,11 @@ bool Identity::locked() const
     return m_locked;
 }
 
+bool Identity::bot() const
+{
+    return m_bot;
+}
+
 QString Identity::visibility() const
 {
     return m_visibility;
@@ -105,6 +110,7 @@ void Identity::fromSourceData(const QJsonObject &doc)
     m_account = doc["acct"_L1].toString();
     m_bio = doc["note"_L1].toString();
     m_locked = doc["locked"_L1].toBool();
+    m_bot = doc["bot"_L1].toBool();
     m_backgroundUrl = QUrl(doc["header"_L1].toString());
     m_avatarUrl = QUrl(doc["avatar"_L1].toString());
     m_followersCount = doc["followers_count"_L1].toInt();
@@ -118,6 +124,8 @@ void Identity::fromSourceData(const QJsonObject &doc)
     // will get empty strings.
     QJsonObject source = doc["source"_L1].toObject();
     m_visibility = source["privacy"_L1].toString();
+    m_lastStatusAt = QDate::fromString(doc["last_status_at"_L1].toString(), Qt::ISODate);
+    m_createdAt = QDate::fromString(doc["created_at"_L1].toString(), Qt::ISODate);
 
     m_displayNameHtml = m_displayName.replace(QLatin1Char('<'), QStringLiteral("&lt;")).replace(QLatin1Char('>'), QStringLiteral("&gt;"));
 
@@ -129,7 +137,7 @@ void Identity::fromSourceData(const QJsonObject &doc)
     const QString baseUrl = m_url.toDisplayString(QUrl::RemovePath);
 
     // Attempt to replace the tag URLs with proper ones, although this should really be handled by the Mastodon API
-    m_bio = m_bio.replace(baseUrl + QStringLiteral("/tags/"), QStringLiteral("hashtag:/"), Qt::CaseInsensitive);
+    m_bio.replace(baseUrl + QStringLiteral("/tags/"), QStringLiteral("hashtag:/"), Qt::CaseInsensitive);
 
     // Even worse, mentions are not given proper ids so we must figure it out on our own.
     // The account could be on a different server, so let's take advantage of web+ap and use that
@@ -145,7 +153,7 @@ void Identity::fromSourceData(const QJsonObject &doc)
             if (captured.contains('@'_L1)) {
                 // The length of "href=" which is used in the regex.
                 const int hrefLength = 6;
-                m_bio = m_bio.replace(start + hrefLength, length - hrefLength, QStringLiteral("web+ap:/") + captured.mid(hrefLength));
+                m_bio.replace(start + hrefLength, length - hrefLength, QStringLiteral("web+ap:/") + captured.mid(hrefLength));
             }
         }
     }
@@ -168,4 +176,14 @@ QUrl Identity::url() const
     return m_url;
 }
 
-#include "moc_identity.cpp"
\ No newline at end of file
+QDate Identity::lastStatusAt() const
+{
+    return m_lastStatusAt;
+}
+
+QString Identity::createdAt() const
+{
+    return TextHandler::getRelativeDate(m_createdAt);
+}
+
+#include "moc_identity.cpp"
