@@ -25,6 +25,7 @@ class Identity : public QObject
     Q_PROPERTY(QString account READ account NOTIFY identityUpdated)
     Q_PROPERTY(QUrl url READ url NOTIFY identityUpdated)
     Q_PROPERTY(bool locked READ locked NOTIFY identityUpdated)
+    Q_PROPERTY(bool bot READ bot NOTIFY identityUpdated)
     Q_PROPERTY(QString visibility READ visibility NOTIFY identityUpdated)
     Q_PROPERTY(QUrl avatarUrl READ avatarUrl NOTIFY identityUpdated)
     Q_PROPERTY(QUrl backgroundUrl READ backgroundUrl NOTIFY identityUpdated)
@@ -34,87 +35,97 @@ class Identity : public QObject
     Q_PROPERTY(int permission READ permission NOTIFY identityUpdated)
     Q_PROPERTY(QJsonArray fields READ fields NOTIFY identityUpdated)
     Q_PROPERTY(Relationship *relationship READ relationship NOTIFY relationshipChanged)
+    Q_PROPERTY(QString createdAt READ createdAt NOTIFY identityUpdated)
 
 public:
     /**
      * @return The numeric ID associated with this identity.
      */
-    QString id() const;
+    [[nodiscard]] QString id() const;
 
     /**
      * @return This identity's display name, if not set then returns the username
      */
-    QString displayName() const;
+    [[nodiscard]] QString displayName() const;
 
     /**
      * @return The username for this identity.
      */
-    QString username() const;
+    [[nodiscard]] QString username() const;
 
     /**
      * @return This identity's display name, but processed as HTML (for custom emojis). If not set, returns the username.
      */
-    QString displayNameHtml() const;
+    [[nodiscard]] QString displayNameHtml() const;
 
     /**
      * @return The biography for this identity.
      */
-    QString bio() const;
+    [[nodiscard]] QString bio() const;
 
     /**
      * @return The account ID for this identity.
      */
-    QString account() const;
+    [[nodiscard]] QString account() const;
 
     /**
      * @return The URL to this identity's profile, which exists on their original server.
      */
-    QUrl url() const;
+    [[nodiscard]] QUrl url() const;
 
     /**
      * @return If this identity is locked or not.
      */
-    bool locked() const;
+    [[nodiscard]] bool locked() const;
+
+    /**
+     * @return If this identity is a bot or not.
+     */
+    [[nodiscard]] bool bot() const;
 
     /**
      * @return The profile visibility.
      */
-    QString visibility() const;
+    [[nodiscard]] QString visibility() const;
 
     /**
      * @return URL to this identity's avatar.
      */
-    QUrl avatarUrl() const;
+    [[nodiscard]] QUrl avatarUrl() const;
 
     /**
      * @return URL to this identity's background.
      */
-    QUrl backgroundUrl() const;
+    [[nodiscard]] QUrl backgroundUrl() const;
 
     /**
      * @return The number of users following this identity.
      */
-    int followersCount() const;
+    [[nodiscard]] int followersCount() const;
 
     /**
      * @return The number of users this identity follows.
      */
-    int followingCount() const;
+    [[nodiscard]] int followingCount() const;
 
     /**
      * @return The number of posts written by this identity.
      */
-    int statusesCount() const;
+    [[nodiscard]] int statusesCount() const;
 
     /**
      * @return The permissions of this identity.
      */
-    int permission() const;
+    [[nodiscard]] int permission() const;
 
     /**
      * @return Custom fields set by this identity.
      */
-    QJsonArray fields() const;
+    [[nodiscard]] QJsonArray fields() const;
+
+    [[nodiscard]] QDate lastStatusAt() const;
+
+    [[nodiscard]] QString createdAt() const;
 
     /**
      * @brief Fills in identity data from JSON.
@@ -131,7 +142,7 @@ public:
     /**
      * @return Our relationship to this identity.
      */
-    Relationship *relationship() const;
+    [[nodiscard]] Relationship *relationship() const;
 
     /**
      * @brief Replaces the existing relationship with a new one.
@@ -160,6 +171,9 @@ private:
     int m_followingCount;
     int m_statusesCount;
     int m_permission;
+    QDate m_lastStatusAt;
     Relationship *m_relationship = nullptr;
     AbstractAccount *m_parent = nullptr;
+    bool m_bot;
+    QDate m_createdAt;
 };
