@@ -26,6 +26,7 @@ class ProfileEditorBackend : public QObject
     Q_PROPERTY(QString avatarUrlError READ avatarUrlError NOTIFY avatarUrlChanged)
     Q_PROPERTY(bool locked READ locked WRITE setLocked NOTIFY lockedChanged)
     Q_PROPERTY(bool discoverable READ discoverable WRITE setDiscoverable NOTIFY discoverableChanged)
+    Q_PROPERTY(QJsonArray fields READ fields WRITE setFields NOTIFY fieldsChanged)
 
 public:
     explicit ProfileEditorBackend(QObject *parent = nullptr);
@@ -34,7 +35,7 @@ public:
     /**
      * @return The account we're updating.
      */
-    AbstractAccount *account() const;
+    [[nodiscard]] AbstractAccount *account() const;
 
     /**
      * @brief Sets the account to edit.
@@ -45,12 +46,12 @@ public:
     /**
      * @return The display name of the account.
      */
-    QString displayName() const;
+    [[nodiscard]] QString displayName() const;
 
     /**
      * @return The display name of the account, processed to HTML (for custom emojis)
      */
-    QString displayNameHtml() const;
+    [[nodiscard]] QString displayNameHtml() const;
 
     /**
      * @brief Sets a new display name for the account.
@@ -61,7 +62,7 @@ public:
     /**
      * @return The biography text for the account.
      */
-    QString note() const;
+    [[nodiscard]] QString note() const;
 
     /**
      * @brief Sets a new biography text for the account.
@@ -72,7 +73,7 @@ public:
     /**
      * @return If the account should be marked as a bot.
      */
-    bool bot() const;
+    [[nodiscard]] bool bot() const;
 
     /**
      * @brief Sets if the account should be marked as a bot.
@@ -83,12 +84,12 @@ public:
     /**
      * @return The current avatar URL for the account.
      */
-    QUrl avatarUrl() const;
+    [[nodiscard]] QUrl avatarUrl() const;
 
     /**
      * @return A localized error if the new avatar failed to upload.
      */
-    QString avatarUrlError() const;
+    [[nodiscard]] QString avatarUrlError() const;
 
     /**
      * @brief Sets a new avatar URL for the account.
@@ -99,12 +100,12 @@ public:
     /**
      * @return The current background URL for the account.
      */
-    QUrl backgroundUrl() const;
+    [[nodiscard]] QUrl backgroundUrl() const;
 
     /**
      * @return A localized error if the new background failed to upload.
      */
-    QString backgroundUrlError() const;
+    [[nodiscard]] QString backgroundUrlError() const;
 
     /**
      * @brief Sets a new background URL for the account.
@@ -115,7 +116,7 @@ public:
     /**
      * @return Whether the account should be discoverable on the server directory.
      */
-    bool discoverable() const;
+    [[nodiscard]] bool discoverable() const;
 
     /**
      * @brief Sets whether the account should be discoverable on the server directory.
@@ -123,10 +124,20 @@ public:
      */
     void setDiscoverable(bool discoverable);
 
+    /**
+     * @return This account's fields.
+     */
+    [[nodiscard]] QJsonArray fields() const;
+
+    /**
+     * @brief Replaces this account's fields with @p fields.
+     */
+    void setFields(const QJsonArray &fields);
+
     /**
      * @return If the account is locked.
      */
-    bool locked() const;
+    [[nodiscard]] bool locked() const;
 
     /**
      * @brief Sets if the account is locked or not.
@@ -137,6 +148,8 @@ public:
 public Q_SLOTS:
     void save();
     void fetchAccountInfo();
+    void setFieldName(int index, const QString &name);
+    void setFieldValue(int index, const QString &value);
 
 Q_SIGNALS:
     void accountChanged();
@@ -147,6 +160,7 @@ Q_SIGNALS:
     void backgroundUrlChanged();
     void discoverableChanged();
     void lockedChanged();
+    void fieldsChanged();
     void sendNotification(const QString &message, const QString &type = QStringLiteral("info"));
 
 private:
@@ -158,4 +172,5 @@ private:
     QUrl m_backgroundUrl;
     bool m_discoverable = true;
     bool m_locked = false;
+    QJsonArray m_fields;
 };
