@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "rulesmodel.h"
+#include "account/rulesmodel.h"
 
 using namespace Qt::Literals::StringLiterals;
 
