@@ -4,6 +4,7 @@
 #include "admin/accounttoolmodel.h"
 
 #include "account/accountmanager.h"
+#include "texthandler.h"
 
 #include <KLocalizedString>
 
@@ -246,7 +247,7 @@ void AccountsToolModel::actionAgainstAccount(const int row, const QString &type,
 bool AccountsToolModel::canFetchMore(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
-    return !m_next.isEmpty() && m_pagination;
+    return m_next.has_value() && m_pagination;
 }
 
 void AccountsToolModel::deleteAccountData(const int row)
@@ -278,7 +279,7 @@ void AccountsToolModel::executeAdminAction(const int row, AdminAccountAction adm
 
     const auto accountId = identity->userLevelIdentity()->id();
 
-    const QString accountApiUrl = QStringLiteral("/api/v1/admin/accounts/") + accountId + apiCall;
+    const QString accountApiUrl = QStringLiteral("/api/v1/admin/accounts/%1%2").arg(accountId, apiCall);
 
     const QJsonDocument doc(extraArguments);
     // to be used when receiving parameter from actionAgainstAccount
@@ -296,7 +297,7 @@ void AccountsToolModel::executeAdminAction(const int row, AdminAccountAction adm
                 {AdminAccountAction::ApproveAccount, i18n("Could not accept account")},
                 {AdminAccountAction::RejectAccount, i18n("Could not reject account")},
                 {AdminAccountAction::ActionAgainstAccount, i18n("Could not take action against the account")},
-                {AdminAccountAction::EnableDisabledAccount, i18n("Could not enable  the disabled account")},
+                {AdminAccountAction::EnableDisabledAccount, i18n("Could not enable the disabled account")},
                 {AdminAccountAction::UnsilenceAccount, i18n("Could not unsilence the account")},
                 {AdminAccountAction::UnsuspendAccount, i18n("Could not unsuspend the account")},
                 {AdminAccountAction::UnmarkSensitiveAccount, i18n("Could not mark the account as not sensitive")},
@@ -375,10 +376,10 @@ void AccountsToolModel::fillTimeline()
     setLoading(true);
 
     QUrl url;
-    if (m_next.isEmpty()) {
+    if (!m_next) {
         url = account->apiUrl(QStringLiteral("/api/v2/admin/accounts"));
     } else {
-        url = m_next;
+        url = m_next.value();
     }
     // To be removed when the pagination api response is fixed
     if (url.toString().contains("v1"_L1)) {
@@ -392,12 +393,9 @@ void AccountsToolModel::fillTimeline()
         const auto accounts = doc.array();
 
         if (!accounts.isEmpty()) {
-            static QRegularExpression re(QStringLiteral("<(.*)>; rel=\"next\""));
-            const auto next = reply->rawHeader(QByteArrayLiteral("Link"));
-            const auto match = re.match(QString::fromUtf8(next));
-            if (re.isValid()) {
-                m_next = QUrl::fromUserInput(match.captured(1));
-            }
+            const auto linkHeader = QString::fromUtf8(reply->rawHeader(QByteArrayLiteral("Link")));
+            m_next = TextHandler::getNextLink(linkHeader);
+
             QList<std::shared_ptr<AdminAccountInfo>> fetchedAccounts;
 
             std::transform(
