@@ -25,12 +25,12 @@ public:
 
     explicit EmailBlockToolModel(QObject *parent = nullptr);
 
-    bool loading() const;
+    [[nodiscard]] bool loading() const;
     void setLoading(bool loading);
 
-    QVariant data(const QModelIndex &index, int role) const override;
-    int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     void filltimeline();
 
@@ -43,5 +43,5 @@ Q_SIGNALS:
 private:
     QList<EmailInfo> m_emailinfo;
     bool m_loading = false;
-    QUrl m_next;
+    std::optional<QUrl> m_next;
 };
