@@ -8,7 +8,7 @@
 using namespace Qt::Literals::StringLiterals;
 
 MockAccount::MockAccount(QObject *parent)
-    : AbstractAccount(parent)
+    : AbstractAccount({}, parent)
 {
     registerGet(apiUrl(QStringLiteral("/api/v1/preferences")), new TestReply(QStringLiteral("preferences.json"), this));
     m_preferences = new Preferences(this);
@@ -20,6 +20,11 @@ MockAccount::MockAccount(QObject *parent)
     Q_EMIT authenticated(true, {});
 }
 
+bool MockAccount::successfullyAuthenticated() const
+{
+    return true;
+}
+
 void MockAccount::get(const QUrl &url,
                       bool authenticated,
                       QObject *parent,
@@ -145,9 +150,8 @@ void MockAccount::buildFromSettings()
 {
 }
 
-void MockAccount::validateToken(bool newAccount)
+void MockAccount::validateToken()
 {
-    Q_UNUSED(newAccount)
 }
 
 void MockAccount::checkForFollowRequests()
