@@ -21,9 +21,9 @@ class TimelineTest : public QObject
 private Q_SLOTS:
     void initTestCase()
     {
+        AccountManager::instance().setTestMode(true);
         account = new MockAccount();
-        AccountManager::instance().addAccount(account, false);
-        AccountManager::instance().selectAccount(account, false);
+        AccountManager::instance().addAccount(account);
     }
 
     void testMainDisplayName()
