@@ -19,12 +19,12 @@ public:
 
     enum ExtraRole { PreviewRole = Qt::UserRole + 1, DescriptionRole, FocalXRole, FocalYRole };
 
-    int count() const;
+    [[nodiscard]] int count() const;
 
-    Q_INVOKABLE int rowCount(const QModelIndex &parent = {}) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
-    QHash<int, QByteArray> roleNames() const override;
-    const QList<Attachment *> &attachments() const;
+    Q_INVOKABLE [[nodiscard]] int rowCount(const QModelIndex &parent = {}) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] const QList<Attachment *> &attachments() const;
 
     void copyFromOther(AttachmentEditorModel *other);
 
@@ -44,7 +44,7 @@ Q_SIGNALS:
 private:
     QList<Attachment *> m_attachments;
     QHash<QString, QTimer *> m_updateTimers;
-    AbstractAccount *m_account;
+    AbstractAccount *m_account = nullptr;
 
     QTemporaryDir m_saveDir;
 };
