@@ -15,11 +15,11 @@ public:
 
     explicit RawLanguageModel(QObject *parent = nullptr);
 
-    QVariant data(const QModelIndex &index, int role) const override;
-    int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
-    Q_INVOKABLE QString getCode(int index) const;
+    Q_INVOKABLE [[nodiscard]] QString getCode(int index) const;
     Q_INVOKABLE QModelIndex indexOfValue(const QString &code);
 
 private:
