@@ -5,8 +5,6 @@
 
 #include <QtQml>
 
-class AbstractAccount;
-
 /**
  * @brief Handles miscenallous operations, mostly a glue between C++ and QML.
  */
@@ -49,7 +47,7 @@ public:
     /**
      * @return Whether or not we have a push notification endpoint available.
      */
-    bool pushNotificationsAvailable() const;
+    [[nodiscard]] bool pushNotificationsAvailable() const;
 
     /**
      * @brief Opens an arbitrary HTML link (post, account, etc URL) if available on the current account's server.
