@@ -76,18 +76,20 @@ public:
 
         PostRole, /** The original Post object. */
 
+        ShowReadMarkerRole, /** Show the read marker above this post */
+
         ExtraRole, /** Base role for sub-class roles. */
     };
 
     explicit AbstractTimelineModel(QObject *parent = nullptr);
 
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     /**
      * @return If the timeline is still loading.
      * @see setLoading()
      */
-    bool loading() const;
+    [[nodiscard]] virtual bool loading() const;
 
     /**
      * @brief Set the loading status of the timeline.
