@@ -1,10 +1,6 @@
 // SPDX-FileCopyrightText: 2023 Shubham Arora <shubhamarora@protonmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include <QJsonArray>
-#include <QJsonObject>
-#include <QUrl>
-
 #include "tag.h"
 
 using namespace Qt::Literals::StringLiterals;
@@ -51,3 +47,5 @@ QString Tag::name() const
 {
     return m_name;
 }
+
+#include "moc_tag.cpp"
\ No newline at end of file
