@@ -20,14 +20,14 @@ public:
     explicit TagsTimelineModel(QObject *parent = nullptr);
     ~TagsTimelineModel() override;
 
-    void fillTimeline(const QString &fromId) override;
-    QString displayName() const override;
+    void fillTimeline(const QString &fromId, bool backwards = false) override;
+    [[nodiscard]] QString displayName() const override;
 
     /**
      * @brief The hashtag the timeline is searching for.
      * @see setHashtag()
      */
-    QString hashtag() const;
+    [[nodiscard]] QString hashtag() const;
 
     /**
      * @brief Sets the hashtag the timeline is searching for.
