@@ -145,11 +145,19 @@ bool TextHandler::isPostUrl(const QString &url)
     }
 
     // TODO: create regex to better whittle down these cases:
-    // Pleroma/Akkoma/Misskey
+    // Misskey
     if (url.contains(QStringLiteral("/notes/"))) {
         return true;
     }
 
+    // Pleroma/Akkoma
+    if (url.contains(QStringLiteral("/objects/"))) {
+        return true;
+    }
+    if (url.contains(QStringLiteral("/notice/"))) {
+        return true;
+    }
+
     // Pixelfed
     if (url.contains(QStringLiteral("/p/"))) {
         return true;
